/* cl_main.c
 * ANDHILL (soccer client for Robocup97)
 * Tomohito Andou <andou@is.titech.ac.jp>
 * Tokyo Institute of Technology
 * Dept of Mathematical and Computing Sciences
 * Copyright (C) 1997 Tomohito Andou
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "client.h"
#include "cl_nn.h"

void main(int argc, char **argv)
{
  char		*server;
  int		port;
  InitInfo	info;
  FILE		*fp;
  char		fname[20];
  int		i;
  int		reconnect_flag;

  strcpy(game_team, "andhill");
  server 		= "localhost";
  port	 		= 6000;
  learn_flag		= 0;
  fixedposi_flag	= 1;
  reconnect_flag	= 0;
  for (i=1; i<argc; i++) {
    if (argv[i][0]!='-' && argv[i][0]!='/') continue;
    switch (argv[i][1]) {
     case 't':
      strcpy(game_team, argv[i+1]);	break;
     case 's':
      server = argv[i+1];		break;
     case 'p':
      port = atoi(argv[i+1]);		break;
     case 'l':
      learn_flag = 1;
      fixedposi_flag = 0;
      break;
     case 'n':
      fixedposi_flag = 0;
      break;
     case 'r':
      reconnect_flag = atoi(argv[i+1]);	break;
     default:
      fprintf(stderr, "Usage: %s [-t TEAMNAME] [-s SERVERHOST] [-p PORT] [-l] [-n] [-r UNUM]\n", argv[0]);
      exit(1);
    }
  }

  sock = init_connection(server,port);

  if (sock.socketfd == -1)
    exit(1);

  if (reconnect_flag == 0)
    info = send_com_init(&sock, game_team);
  else {
    info = send_com_reconnect(&sock, game_team, reconnect_flag);
    info.unum = reconnect_flag;
  }

#if 0
  printf("\ninit!: %d, %d, %s, %d\n\n",
	 info.side, info.unum, info.playmodestr, info.playmode);
#endif
  usleep(WAIT_TIME);

  if (fixedposi_flag == 0) {
    sprintf(fname, "%s%02d.pos", game_team, info.unum);
    if ((fp = fopen(fname, "r")) == NULL) {
      fprintf(stderr, "%s: can't read.\n", fname);
      exit(1);
    }
    posi_input(fp);
    fclose(fp);
  }

  initialize();

  game_time	= 0;
  game_side	= info.side;
  game_unum	= info.unum;
  get_mode(info.playmodestr);

  if (info.side == S_UNKNOWN) {
    printf("Can't init\n");
    exit(-1);
  }
  message_loop(stdin, stdout);

  close_connection(sock);
}

/* End Of File */
