/* client.h
 * ANDHILL (soccer client for Robocup97)
 * Tomohito Andou <andou@is.titech.ac.jp>
 * Tokyo Institute of Technology
 * Dept of Mathematical and Computing Sciences
 * Copyright (C) 1997 Tomohito Andou
 */

#ifndef CLIENT_H
#define CLIENT_H

#include <libsclient.h>

#define WAIT_TIME	(100000)
#define GOAL_WIDTH	(14.02)
#define PL_SIZE		(0.8)
#define PL_DECAY	(0.4)
#define BALL_SIZE	(0.085)
#define BALL_DECAY	(0.96)
#define STAMINA_MAX	(2000)
#define STAMINA_INC	(20)
#define DASH_RATE	(0.01)
#define KICK_RATE	(0.013)
#define AUDIO_RADIUS	(50)
#define POWER_MAX	(100)
#define POWER_MIN	(-30)

#define PL_ONESTEP	(1.6)	/* (1.0 / (1.0-PL_DECAY)) */
#define BALL_ONESTEP	(25)	/* (1.0 / (1.0-BALL_DECAY)) */
#define BALL_DISTANCE	(32.5)	/* (1.3 / (1.0-BALL_DECAY)) */

#define SMALL_X		(16)
#define SMALL_Y		(11)
#define S2Lx(x)	(((x)-(SMALL_X/2.0-0.5)) * PITCH_LENGTH / SMALL_X)
#define S2Ly(y)	(((y)-(SMALL_Y/2.0-0.5)) * PITCH_WIDTH / SMALL_Y)
#define L2Sx(x)	((int) (restrict((x)+PITCH_LENGTH/2,0,PITCH_LENGTH-0.1) \
			* SMALL_X / PITCH_LENGTH))
#define L2Sy(y)	((int) (restrict((y)+PITCH_WIDTH/2,0,PITCH_WIDTH-0.1) \
			* SMALL_Y / PITCH_WIDTH))
#define restrict(x,min,max) ((x)<(min)?(min):(x)>(max)?(max):(x))
#define regDeg(x) ((x)<-180?(x)+360:((x)>180?(x)-360:(x)))

void message_loop(FILE* fpin, FILE* fpout);
void ball_estimate(void);
void action(void);
void calc_reward(void);
void position(void);
void init_position(void);
int chase(void);
void go_abs(double ox, double oy);
void go(double odir, double odist);
void pass(void);
void kick(double kick_x, double kick_y);
void dash(double dash_pow);
void turn(double turn_dir);
void move(double x, double y);
void get_mode(char* message);
void say(void);
void hear(HearInfo info);
void see(SeeInfo info);
void show(void);
void initialize(void);

extern Socket		sock;
extern int		learn_flag;
extern int		fixedposi_flag;

extern long		game_time;
extern char		game_team[16];
extern Side		game_side;
extern int		game_unum;
extern int		game_mode;

extern long		my_time;
extern double		my_x;
extern double		my_y;
extern int		my_Sx;
extern int		my_Sy;
extern double		my_dir;
extern int		my_stamina;
extern int		my_view;	/* 45,90,180 */
extern double		my_gox;
extern double		my_goy;

extern long		my_vel_time;
extern double		my_vel_x;
extern double		my_vel_y;
extern double		my_vel;

extern long		ball_time;
extern double		ball_x;
extern double		ball_y;
extern int		ball_Sx;
extern int		ball_Sy;
extern double		ball_dir;
extern double		ball_dist;
extern double		ball_ex;
extern double		ball_ey;

extern long		ball_vel_time;
extern double		ball_vel_x;
extern double		ball_vel_y;
extern double		ball_vel;

extern long		map_time;
extern char		map_char[SMALL_X][SMALL_Y];
extern double		sc_base[SMALL_X][SMALL_Y][2];

extern int		info_flag;
extern int		turn_flag;
extern int		seebl_flag;
extern int		reached_posi;
extern int		reached_ball;
extern int		last_say;
extern int		last_reward;
extern int		last_posi;

extern SeenObj		nearest_player;
extern SeenObj		seen_player[21];
extern int		seen_num;
extern SeenObj		nearest_enemy;
extern int		seen_enemy;

#endif

/* End Of File */
